RatingButtonThemeData class
Constructors
- RatingButtonThemeData({double? minWidth, double? height, TextStyle? activeTextStyle, Color? activeColor, Color? inActiveColor, TextStyle? inActiveTextStyle, Color? highlightColor, Color? splashColor, ShapeBorder? shape, double? elevation, EdgeInsetsGeometry? padding, VisualDensity? visualDensity, double spacing = 0.0, double runSpacing = 0.0, WrapAlignment alignment = WrapAlignment.start, WrapCrossAlignment crossAxisAlignment = WrapCrossAlignment.start})
-
const
Properties
- activeColor → Color?
-
Set button backgroundColor when selected
final
- activeTextStyle → TextStyle?
-
Set button text style when selected
final
- alignment → WrapAlignment
-
How the each rating button within a run should be placed in the main axis.
final
- crossAxisAlignment → WrapCrossAlignment
-
How the each rating button within a run should be aligned relative to each other in the cross axis.
final
- elevation → double?
-
This controls the size of the shadow below the raised button.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
Set height of button
final
- highlightColor → Color?
-
The highlight indicates that the button is actively being pressed.
final
- inActiveColor → Color?
-
Set button backgroundColor when unselected
final
- inActiveTextStyle → TextStyle?
-
Set button text when unselected
final
- minWidth → double?
-
Set minimum width of button
final
- padding → EdgeInsetsGeometry?
-
The internal padding for the button.
final
- runSpacing → double
-
How much space to place between the each rating button themselves in the cross axis.
For example, if runSpacing is 10.0, the each rating button will be spaced at least 10.0 logical pixels apart in the cross axis.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shape → ShapeBorder?
-
The button's highlight and splash are clipped to this shape. If the button has an elevation, then its drop shadow is defined by this shape as well.
final
- spacing → double
-
How much space to place between each rating button in a run in the main axis.
final
- splashColor → Color?
-
The ink splash indicates that the button has been touched.
final
- visualDensity → VisualDensity?
-
Defines how compact the button's layout will be.
final
Methods
-
copyWith(
{double? minWidth, double? height, TextStyle? activeTextStyle, TextStyle? inActiveTextStyle, Color? inActiveColor, Color? activeColor, Color? textColor, Color? highlightColor, Color? splashColor, ShapeBorder? shape, double? elevation, EdgeInsetsGeometry? padding, VisualDensity? visualDensity, double? spacing, double? runspacing, WrapAlignment? alignment, WrapCrossAlignment? crossAxisAlignment}) → RatingButtonThemeData -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- circular → RatingButtonThemeData
-
no setter
- defaultTheme → RatingButtonThemeData
-
no setter
Static Methods
-
circularOutlined(
{Color color = const Color(4278190080), double width = 1.0, BorderStyle style = BorderStyle.solid}) → RatingButtonThemeData -
outlinedBorder(
{Color borderColor = Colors.grey, double borderWidth = 1.0, BorderStyle borderStyle = BorderStyle.solid, double borderRadius = 4.0}) → RatingButtonThemeData -
roundedBorder(
{BorderSide side = BorderSide.none, BorderRadiusGeometry borderRadius = BorderRadius.zero}) → RatingButtonThemeData